@@ -1,5 +1,8 @@
 import fire
 from show_anything.core import core, save_images, show_images
+from PIL import TiffTags
+
+
 
 
 def save(
@@ -49,13 +52,9 @@ def show_me(
     tf_img = core(prompt, batch_size, guidance_scale, upsample_temp)
     show_images(tf_img)
 
-
-def show_a(*args, **kwargs):
-    show_me_a(*args, **kwargs)
-
-
-def show(*args, **kwargs):
-    show_me_a(*args, **kwargs)
+# function alias
+show_a = show_me
+show = show_me
 
 
 def cli():
