@@ -253,6 +253,25 @@ def upsample_the_64x64_samples(
     model_up.del_cache()
     return up_samples
 
+def reload_pillow():
+    modules = sys.modules.copy()
+    for name, module in modules.items():
+      if 'PIL' in name or 'image' in name:
+        try:
+          reload(module)
+        except:
+          pass
+    
+    check_pillow_import()
+
+
+def check_pillow_import():
+    try:
+        from PIL.TiffTags import IFD
+    except:
+        raise ValueError("You need to restart the runtime after installing the package. ")
+
+
 def core(
     prompt,
     batch_size: int,
@@ -270,7 +289,7 @@ def core(
     Returns:
 
     """
-
+    reload_pillow()
     print(f"Generate image of '{prompt}':")
     samples = sample_from_base_model(prompt, batch_size, guidance_scale)
     up_samples = upsample_the_64x64_samples(samples, prompt, batch_size, upsample_temp)
